==> wildfly-camel-subsystem-security-7.0.0-sources.jar: org/wildfly/extension/camel/security/EncodedUsernamePasswordPrincipal.java <==
/*
 * #%L
 * Wildfly Camel :: Subsystem
 * %%
 * Copyright (C) 2013 - 2014 RedHat
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

package org.wildfly.extension.camel.security;

import org.jboss.crypto.CryptoUtil;
import org.jboss.gravia.utils.IllegalArgumentAssertion;

/**
 * An encoded username password pricipal
 *
 * @author Thomas.Diesler@jboss.com
 * @since 28-Oct-2015
 */
public class EncodedUsernamePasswordPrincipal extends UsernamePasswordPrincipal {

    public EncodedUsernamePasswordPrincipal(String username, char[] password) {
        this("ApplicationRealm", username, password);
    }

    public EncodedUsernamePasswordPrincipal(String realm, String username, char[] password) {
        super(username, encryptPassword(realm, username, password));
    }

    public static char[] encryptPassword(String realm, String username, char[] password) {
        IllegalArgumentAssertion.assertNotNull(realm, "realm");
        IllegalArgumentAssertion.assertNotNull(username, "username");
        IllegalArgumentAssertion.assertNotNull(password, "password");
        String compined = username + ":" + realm + ":" + new String(password);
        return CryptoUtil.createPasswordHash("MD5", "hex", null, null, compined).toCharArray();
    }

}

==> wildfly-camel-subsystem-security-8.0.0-sources.jar: org/wildfly/extension/camel/security/EncodedUsernamePasswordPrincipal.java <==
/*
 * #%L
 * Wildfly Camel :: Subsystem
 * %%
 * Copyright (C) 2013 - 2014 RedHat
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

package org.wildfly.extension.camel.security;

import org.jboss.crypto.CryptoUtil;
import org.wildfly.camel.utils.IllegalArgumentAssertion;

/**
 * An encoded username password pricipal
 *
 * @author Thomas.Diesler@jboss.com
 * @since 28-Oct-2015
 */
public class EncodedUsernamePasswordPrincipal extends UsernamePasswordPrincipal {

    public EncodedUsernamePasswordPrincipal(String username, char[] password) {
        this("ApplicationRealm", username, password);
    }

    public EncodedUsernamePasswordPrincipal(String realm, String username, char[] password) {
        super(username, encryptPassword(realm, username, password));
    }

    public static char[] encryptPassword(String realm, String username, char[] password) {
        IllegalArgumentAssertion.assertNotNull(realm, "realm");
        IllegalArgumentAssertion.assertNotNull(username, "username");
        IllegalArgumentAssertion.assertNotNull(password, "password");
        String compined = username + ":" + realm + ":" + new String(password);
        return CryptoUtil.createPasswordHash("MD5", "hex", null, null, compined).toCharArray();
    }

}
